@@ -71,19 +71,19 @@ class PySystemAir():
         """
         try:
             result=None
-            _LOGGER.warning(f"register.addr == {register.addr}")
-            _LOGGER.warning(f"register.reg_type == {register.reg_type}")
+            # _LOGGER.warning(f"register.addr == {register.addr}")
+            # _LOGGER.warning(f"register.reg_type == {register.reg_type}")
             if register.reg_type == REG_TYPE.INPUT:
-                _LOGGER.warning(f"calling {self._async_callbacks.input_reg}")
+                # _LOGGER.warning(f"calling {self._async_callbacks.input_reg}")
                 result = await self._async_callbacks.input_reg(address=register.addr)
             elif register.reg_type == REG_TYPE.HOLDING:
-                _LOGGER.warning(f"calling {self._async_callbacks.holding_reg}")
+                # _LOGGER.warning(f"calling {self._async_callbacks.holding_reg}")
                 result = await self._async_callbacks.holding_reg(address=register.addr)
 
             if result is None:
                  _LOGGER.warning(f"Error reading {key} value from SystemAir modbus adapter")
             else:
-                _LOGGER.warning(f"{key} value is {result.registers[0]}")
+                # _LOGGER.warning(f"{key} value is {result.registers[0]}")
                 register.value = result.registers[0]
         except AttributeError as e:
             raise e
@@ -93,9 +93,13 @@ class PySystemAir():
         """
         Updates all of the input and holding regs dict values.
         """
+        # TODO: if register.reg_type != REG_TYPE.HOLDING:
+        #     raise ERROR
+        _LOGGER.warning(f"async_write_to_register") 
         try:
             if await self._async_callbacks.write_reg(address=register.addr, value=value):
-                    register.value = value
+                _LOGGER.warning(f"Successfully set {value} to register {register.addr}") 
+                register.value = value
             else:
                 _LOGGER.error(f"Unable to write {value} to register {register.addr}") 
         except AttributeError as e:
@@ -217,6 +221,13 @@ class PySystemAir():
             return 0
         return registers.pdm_humidity_sensor.value
 
+    @property
+    def humidity_transfer_enabled(self):
+        """Return the temperature we try to reach."""
+        if registers.humidity_transfer_enabled.value is None:
+            return 0
+        return registers.humidity_transfer_enabled.value
+
     @property
     def target_humidity(self):
         """Return the temperature we try to reach."""
@@ -258,12 +269,19 @@ class PySystemAir():
         await self.async_write_to_register(registers.eaf_usermode_fs, value)
 
 
-    async def async_set_humidity(self, value):
+    async def async_set_humidity(self, value:int):
         """Set new target temperature."""
         value=int(round(value))
         await self.async_write_to_register(registers.target_humidity, value)
         
 
-    async def async_cotwo_meas(self, value):
+    async def async_set_cotwo_meas(self, value:int):
         """Set new target temperature."""
-        await self.async_write_to_register(registers.co2_sensor, value)
\ No newline at end of file
+        _LOGGER.error(f"Calling async_cotwo_meas with value {value}") 
+        await self.async_write_to_register(registers.co2_sensor, value)
+
+
+    async def async_set_free_cooling(self, state:bool):
+        """Set new target temperature."""
+        _LOGGER.error(f"Calling async_set_free_cooling with state {state}") 
+        await self.async_write_to_register(registers.free_cooling_enabled, state)
\ No newline at end of file
